@@ -7,6 +7,7 @@ use strict;
 
 use Crypt::PRNG qw(irand);
 use Crypt::Misc 0.029 qw(decode_b64 encode_b64);
+use File::KDBX 0.900;
 use File::KDBX::Constants qw(:header :magic :version);
 use File::KDBX::Loader::KDB;
 use File::KDBX::Util qw(clone_nomagic generate_uuid load_optional);
@@ -16,7 +17,7 @@ use Scalar::Util qw(blessed looks_like_number weaken);
 use boolean;
 use namespace::clean;
 
-our $VERSION = '0.900'; # VERSION
+our $VERSION = '0.901'; # VERSION
 
 fieldhashes \my (%KDBX, %TIED);
 
@@ -91,7 +92,7 @@ sub kdbx {
         $self->clear;
         $KDBX{$self} = shift;
     }
-    $KDBX{$self} //= do { require File::KDBX; File::KDBX->new };
+    $KDBX{$self} //= File::KDBX->new;
 }
 
 
@@ -285,7 +286,7 @@ sub add_group {
     $group->{expires} //= $self->default_exp;
 
     my $group_info = File::KDBX::Loader::KDB::_convert_keepass_to_kdbx_group($group);
-    my $group_obj = $self->kdbx->add_group($group_info, parent => $parent);
+    my $group_obj = $self->kdbx->add_group($group_info, group => $parent);
     return $self->_tie({}, 'Group', $group_obj);
 }
 
@@ -348,7 +349,7 @@ sub add_entry {
 
     my $entry_info = File::KDBX::Loader::KDB::_convert_keepass_to_kdbx_entry($entry);
     $parent = $self->kdbx->root->groups->[0] if !$parent && $self->kdbx->_has_implicit_root;
-    my $entry_obj = $self->kdbx->add_entry($entry_info, parent => $parent);
+    my $entry_obj = $self->kdbx->add_entry($entry_info, group => $parent);
     return $self->_tie({}, 'Entry', $entry_obj);
 }
 
@@ -543,7 +544,7 @@ File::KeePass::KDBX - Read and write KDBX files (using the File::KDBX backend)
 
 =head1 VERSION
 
-version 0.900
+version 0.901
 
 =head1 SYNOPSIS
 
